@@ -11,7 +11,11 @@
 #include "framework.h"
 
 #include <filesystem>
+#include <fstream>
 #include <string>
+#include <regex>
+
+#include <strsafe.h>
 
 #include <shlobj_core.h>
 #include <shlwapi.h>
